import { Component, Injectable, OnInit } from '@angular/core';
import {
  ScheduleService
} from '../../projects/lib-ng-service-schedule/src/public_api';
import { Schedule } from '@sec-spec/sis-model-schedule';

/** Main class for the wrapper application. */
@Component({
  selector: 'app-root',
  styleUrls: ['./app.component.scss'],
  templateUrl: './app.component.html',
})
@Injectable()
export class AppComponent implements OnInit {

  createdSchedules: Schedule[];
  schedules: Schedule[];

  constructor(private scheduleService: ScheduleService) {
    // No action
  }

  /** Create a new demo schedule. */
  createSchedule(): void {
    const tmp = Schedule.deserialize({
      is_non_standard: false,
      shifts: [
        {
          day_offset: 1,
          duration: 510,
          schedule_id: null,
          time_start: '06:00',
          type: 'day'
        },
        {
          day_offset: 2,
          duration: 510,
          schedule_id: null,
          time_start: '06:00',
          type: 'day'
        },
        {
          day_offset: 3,
          duration: 510,
          schedule_id: null,
          time_start: '06:00',
          type: 'day'
        },
        {
          day_offset: 4,
          duration: 510,
          schedule_id: null,
          time_start: '06:00',
          type: 'day'
        },
        {
          day_offset: 5,
          duration: 510,
          schedule_id: null,
          time_start: '06:00',
          type: 'day'
        }
      ]
    });
    this.createdSchedules = [];
    this.scheduleService
      .createSchedules([tmp, tmp])
      .subscribe((data: any[]) => {
        const ids: number[] = [];
        for (const item of data) {
          ids.push(item.id as number);
        }
        this.getCreatedSchedules(ids);
      });
  }

  /** Get schedules that were created using the 'Create' button.
   * @param ids Schedule ids.
   */
  private getCreatedSchedules(ids: number[]): void {
    this.scheduleService
      .getSchedules(ids)
      .subscribe((schedules: Schedule[]) => {
        this.createdSchedules = schedules;
      });
  }

  /** Load a schedule when the component is initialized. */
  ngOnInit() {
    this.scheduleService
      .getSchedule(1)
      .subscribe((schedule: Schedule) => {
        this.schedules = [schedule];
      });
  }

  /** Update the test schedules created by the 'Create' button. */
  updateSchedule(): void {
    const ids = [];
    for (const schedule of this.createdSchedules) {
      ids.push(schedule.id);
      schedule.isNonStandard = true;
    }
    this.scheduleService
      .updateSchedules(this.createdSchedules)
      .subscribe(() => {
        this.getCreatedSchedules(ids);
      });
  }

}
